<?php
// Set the content width based on the theme's design and stylesheet
if ( ! isset( $content_width ) ) {
	$content_width = 580;
}

//Set version constant
define( 'STEAMPUNK_VERSION', '2.1' );

// Theme setup
if ( ! function_exists( 'steampunk_setup' ) ) {
	function steampunk_setup() {
		// Menus
		register_nav_menus( array(
			'primary' => __( 'Primary Menu', 'steampunk-lite' ),
		) );

		// Add theme support
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'custom-logo', array(
			'width'       => 400,
			'height'      => 150,
			'flex-height' => true,
			'flex-width'  => true,
		) );
		$defaults = array(
			'default-color' => 'ffffff',
		);
		add_theme_support( 'custom-background', $defaults );

		// Available for translation
		load_theme_textdomain( 'steampunk-lite', get_template_directory() . '/languages' );
	}
}
add_action( 'after_setup_theme', 'steampunk_setup' );

// Register widget area
function steampunk_widgets_init() {
	register_sidebar( array(
		'name'          => __( 'Sidebar', 'steampunk-lite' ),
		'id'            => 'sidebar',
		'description'   => '',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget'  => '</div>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}

add_action( 'widgets_init', 'steampunk_widgets_init' );

// Enqueue scripts and styles
function steampunk_scripts() {
	wp_enqueue_style( 'steampunk-style', get_template_directory_uri() . '/style-min.css', array(), STEAMPUNK_VERSION );
	wp_enqueue_style( 'steampunk-google-fonts', 'https://fonts.googleapis.com/css?family=Rubik:400,500&amp;subset=cyrillic,latin-ext', STEAMPUNK_VERSION );

	wp_enqueue_script( 'steampunk-nprogress', get_template_directory_uri() . '/assets/js/nprogress.min.js', array( 'jquery' ), STEAMPUNK_VERSION, true );
	wp_enqueue_script( 'steampunk-customjs', get_template_directory_uri() . '/assets/js/custom-min.js', array(), STEAMPUNK_VERSION, true );
	wp_localize_script( 'steampunk-ajax', 'ajax', array( 'url' => admin_url( 'admin-ajax.php' ) ) );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'wp_enqueue_scripts', 'steampunk_scripts' );

// Welcome and Dashboard > Appearance item
require_once get_template_directory() . '/welcome/class-brutalist-welcome.php';

// Item in Dashboard > Appearance
$config = array(
	'menu_name'       => __( 'Steampunk Lite', 'steampunk-lite' ),
	'page_name'       => __( 'Steampunk Lite', 'steampunk-lite' ),
	'welcome_title'   => sprintf( __( 'Welcome to %s', 'steampunk-lite' ), 'Steampunk Lite' ),
	'welcome_content' => esc_html__( 'Steampunk Lite is a brutalist WordPress blog theme with a steampunk core.', 'steampunk-lite' ),

	// Tabs
	'tabs'            => array(
		'getting_started' => __( 'Getting Started', 'steampunk-lite' ),
		'lite_pro'        => __( 'Lite vs. PRO', 'steampunk-lite' ),
	),
	// Getting started tab
	'getting_started' => array(
		'gs_customizer'    => array(
			'title'               => esc_html__( 'Customizer', 'steampunk-lite' ),
			'text'                => esc_html__( 'Customize background, add social media icons, or upload a logo.', 'steampunk-lite' ),
			'button_label'        => esc_html__( 'Go to the Customizer', 'steampunk-lite' ),
			'button_link'         => esc_url( admin_url( 'customize.php' ) ),
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
		'gs_documentation' => array(
			'title'               => esc_html__( 'Theme Documentation', 'steampunk-lite' ),
			'text'                => esc_html__( 'Please note that the documentation also includes all the features available in the PRO version, that are not included in the free version.', 'steampunk-lite' ),
			'button_label'        => esc_html__( 'Read the Documentation', 'steampunk-lite' ),
			'button_link'         => 'https://brutalistthemes.com/documentations/steampunk-theme-documentation/',
			'is_button'           => false,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
		'gs_demo'          => array(
			'title'               => esc_html__( 'Theme Demo', 'steampunk-lite' ),
			'text'                => esc_html__( 'Check out the Steampunk PRO theme demo at SteampunkTheme.com', 'steampunk-lite' ),
			'button_label'        => esc_html__( 'View demo', 'steampunk-lite' ),
			'button_link'         => 'https://steampunktheme.com/',
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
		'gs_go_pro'        => array(
			'title'               => esc_html__( 'Go PRO for the price of 2 coffees!', 'steampunk-lite' ),
			'text'                => esc_html__( 'See "Lite vs. PRO" tab for details.', 'steampunk-lite' ),
			'button_label'        => esc_html__( 'Get Steampunk PRO', 'steampunk-lite' ),
			'button_link'         => 'https://brutalistthemes.com/downloads/steampunk/',
			'is_button'           => true,
			'recommended_actions' => false,
			'is_new_tab'          => true,
		),
	),
	// Free vs PRO
	'lite_pro'        => array(
		'free_name' => 'Steampunk Lite',
		'pro_name'  => 'Steampunk PRO',
		'pro_link'  => 'https://brutalistthemes.com/downloads/steampunk/',
		'pro_label' => sprintf( __( 'Get %s', 'steampunk-lite' ), 'Steampunk PRO' ),
		'features'  => array(
			array(
				'title'      => __( 'Responsive layout', 'steampunk-lite' ),
				'is_in_lite' => 'true',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Logo upload', 'steampunk-lite' ),
				'is_in_lite' => 'true',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Social media profile icons', 'steampunk-lite' ),
				'is_in_lite' => 'true',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Built-in schema.org structured data markup', 'steampunk-lite' ),
				'is_in_lite' => 'true',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Customizable background', 'steampunk-lite' ),
				'is_in_lite' => 'true',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Amazing premium steampunk illustrations', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Customizable colors', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Custom "About" widget', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Built-in Signature image upload option', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Built-in Related Articles section', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Built-in Social Media share buttons', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Yoast SEO Breadcrumbs', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
			array(
				'title'      => __( 'Priority Support', 'steampunk-lite' ),
				'is_in_lite' => 'false',
				'is_in_pro'  => 'true',
			),
		),
	),
);
brutalist_dash_page::init( $config );

// Includes

require get_template_directory() . '/inc/common.php';
require get_template_directory() . '/inc/customizer.php';
